# Conditional build:
%bcond_without  python2 # Python 2.x module
%bcond_without  python3 # Python 3.x module

# During its initialization, PycURL checks that the actual libcurl version
# is not lower than the one used when PycURL was built.
# Yes, that should be handled by library versioning (which would then get
# automatically reflected by rpm).
# For now, we have to reflect that dependency.
%define		libcurl_ver %(rpm -q --qf '%|E?{%{E}:}|%{V}' curl-devel | sed 's/package .* is not installed/ERROR/' || echo ERROR)

%define 	module	pycurl
Summary:	Free and easy-to-use client-side URL transfer library
Summary(pl.UTF-8):	Łatwa w użyciu biblioteka obsługi URL od strony klienta
Name:		python-%{module}
Version:	7.19.5.1
Release:	5
License:	LGPL v2 or MIT-like
Group:		Libraries/Python
Source0:	http://pycurl.sourceforge.net/download/%{module}-%{version}.tar.gz
# Source0-md5:	f44cd54256d7a643ab7b16e3f409b26b
Patch0:		%{name}-no-static-libs.patch
URL:		http://pycurl.sourceforge.net/
BuildRequires:	curl-devel >= 7.19
BuildRequires:	pkgconfig >= 1:0.20
%if %{with python2}
BuildRequires:	python >= 1:2.5
BuildRequires:	python-devel >= 1:2.5
BuildRequires:	python-modules >= 1:2.5
%endif
%if %{with python3}
BuildRequires:	python3
BuildRequires:	python3-devel
BuildRequires:	python3-modules
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.219
%pyrequires_eq	python-libs
Requires:	curl-libs >= %{libcurl_ver}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
pycurl is Python interface to curl library - free and easy-to-use
client-side URL transfer library, supporting FTP, FTPS, HTTP, HTTPS,
GOPHER, TELNET, DICT, FILE and LDAP. libcurl supports HTTPS
certificates, HTTP POST, HTTP PUT, FTP uploading, kerberos, HTTP form
based upload, proxies, cookies, user+password authentication, file
transfer resume, HTTP proxy tunneling and more!

%description -l pl.UTF-8
pycurl jest interfejsem języka Python do biblioteki libcurl -
wolnodostępnej i łatwej w użyciu biblioteki operacji na URL-ach od
strony klienta, obsługującej FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET,
DICT, FILE i LDAP. libcurl obsługuje także certyfikaty HTTPS, HTTP
POST, HTTP PUT, uploady FTP, kerberos, upload plików przez HTTP oparty
na formularzach, proxy, ciasteczka, uwierzytelnienie, wznawianie
przesyłania plików, tunelowanie proxy i wiele innych.

%package -n python3-pycurl
Summary:	Free and easy-to-use client-side URL transfer library
Summary(pl.UTF-8):	Łatwa w użyciu biblioteka obsługi URL od strony klienta
Group:		Libraries/Python
%pyrequires_eq	python3-libs
Requires:	curl-libs >= %{libcurl_ver}

%description -n python3-pycurl
pycurl is Python interface to curl library - free and easy-to-use
client-side URL transfer library, supporting FTP, FTPS, HTTP, HTTPS,
GOPHER, TELNET, DICT, FILE and LDAP. libcurl supports HTTPS
certificates, HTTP POST, HTTP PUT, FTP uploading, kerberos, HTTP form
based upload, proxies, cookies, user+password authentication, file
transfer resume, HTTP proxy tunneling and more!

%description -n python3-pycurl -l pl.UTF-8
pycurl jest interfejsem języka Python do biblioteki libcurl -
wolnodostępnej i łatwej w użyciu biblioteki operacji na URL-ach od
strony klienta, obsługującej FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET,
DICT, FILE i LDAP. libcurl obsługuje także certyfikaty HTTPS, HTTP
POST, HTTP PUT, uploady FTP, kerberos, upload plików przez HTTP oparty
na formularzach, proxy, ciasteczka, uwierzytelnienie, wznawianie
przesyłania plików, tunelowanie proxy i wiele innych.

%package doc
Summary:	Documentation for pycurl Python module
Summary(pl.UTF-8):	Dokumentacja do modułu Pythona pycurl
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description doc
This module contains documentation files for pycurl Python module.

%description doc -l pl.UTF-8
Moduł zawierający dokumentację dla modułu Pythona pucurl.

%package examples
Summary:	Examples for pycurl Python module
Summary(pl.UTF-8):	Przykładowe programy do modułu Pythona pycurl
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description examples
This module contains examples for pycurl Python module.

%description examples -l pl.UTF-8
Moduł zawierający przykładowe programy do modułu Pythona pycurl.

%prep
%setup -q -n %{module}-%{version}
%patch0 -p1

%build
%if %{with python2}
CC="%{__cc}" \
CFLAGS="%{rpmcflags}" \
LDFLAGS="%{rpmldflags}" \
%{__python} setup.py build --build-base build-2 \
	--debug
%endif

%if %{with python3}
CC="%{__cc}" \
CFLAGS="%{rpmcflags}" \
LDFLAGS="%{rpmldflags}" \
%{__python3} setup.py build --build-base build-3 \
	--debug
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{py_sitedir},%{_examplesdir}/%{name}-%{version}}

%if %{with python2}
%{__python} setup.py \
	build --build-base build-2 \
	install --skip-build \
	--root=$RPM_BUILD_ROOT \
	--optimize=2

%py_postclean
%endif

%if %{with python3}
%{__python3} setup.py \
	build --build-base build-3 \
	install --skip-build \
	--root=$RPM_BUILD_ROOT \
	--optimize=2
%endif

cp -a examples/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/pycurl

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING-MIT ChangeLog README.rst RELEASE-NOTES.rst
%attr(755,root,root) %{py_sitedir}/pycurl.so
%dir %{py_sitedir}/curl
%{py_sitedir}/curl/*.py[co]
%{py_sitedir}/pycurl-*.egg-info
%endif

%if %{with python3}
%files -n python3-pycurl
%defattr(644,root,root,755)
%attr(755,root,root) %{py3_sitedir}/pycurl*.so
%dir %{py3_sitedir}/curl
%{py3_sitedir}/curl/__pycache__
%{py3_sitedir}/curl/*.py
%{py3_sitedir}/pycurl-*.egg-info
%endif

%files doc
%defattr(644,root,root,755)
# TODO: use rst2html to convert?
#%doc doc/*.html
%doc doc/*.rst

%files examples
%defattr(644,root,root,755)
%{_examplesdir}/%{name}-%{version}
%changelog
* Mon Sep 14 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-pycurl.git;a=log;h=master

* Mon Sep 14 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> ac48673
- release 5 (by relup.sh)

* Sun Sep 13 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> e65d2a2
- python 3.5 rebuild
- release 4 (by relup.sh)

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 7736e48
- x32 rebuild
- release 3 (by relup.sh)

* Sat Jan 24 2015 Marcin Banasiak <marcin.banasiak@gmail.com> 68079f5
- Build python3 module. Release 2

* Sun Jan 11 2015 Jakub Bogusz <qboosh@pld-linux.org> fe8d281
- updated to 7.19.5.1

* Sun Jul 13 2014 Jakub Bogusz <qboosh@pld-linux.org> fcd448f
- updated to 7.19.5

* Sun Feb 09 2014 Jakub Bogusz <qboosh@pld-linux.org> c50d3fa
- updated to 7.19.3.1
- updated no-static-libs patch

* Thu Oct 17 2013 Jakub Bogusz <qboosh@pld-linux.org> 65ea823
- updated to 7.19.0.2
- updated no-static-libs patch to different approach: pycurl needs to check all dependent
  libraries to catch kind of SSL library; but take "static libs" part from pkg-config,
  which returns all libraries in -l form, not from curl-config which returns static
  library path; rely on as-needed machanism to drop unwanted libs from linking

* Wed Aug 03 2011 Jan Rękorajski <baggins@pld-linux.org> d9fa7b9
- release 8

* Fri Dec 03 2010 Jakub Bogusz <qboosh@pld-linux.org> 6624131
- it is dual-licensed (LGPL/MIT-like)

* Sat Nov 13 2010 pawelz <pawelz@pld-linux.org> 4e1aa53
- release 7

* Thu Jul 08 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 81878d8
- release 6

* Mon Jun 07 2010 hawk <hawk@pld-linux.org> ac68a26
- release 5

* Mon Apr 12 2010 Jan Rękorajski <baggins@pld-linux.org> 591b94b
- rel 4

* Sun Apr 11 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 43d44e3
- release 3

* Wed Feb 03 2010 sparky <sparky@pld-linux.org> 60fb6c2
- fix parsing error if curl-devel is not installed

* Wed Feb 03 2010 Elan Ruusamäe <glen@pld-linux.org> efb0ee8
- add no static libs patch from fc
- curl-libs dep based on built curl-devel
- rel 2

* Wed Feb 03 2010 Elan Ruusamäe <glen@pld-linux.org> 1956b3f
- from fc

* Tue Feb 02 2010 Mateusz Korniak <matkor@pld-linux.org> 489c9ba
- Version 7.19.0

* Mon Dec 14 2009 Jan Rękorajski <baggins@pld-linux.org> 79eee10
- rel 6

